#! /bin/sh
#-----------------------------------------------------------------------------
# /var/install/config.d/usb-update.sh - paramater update script
#
# Creation   :  2006-11-09 hbfl
# Last update:  $Id: usb-update.sh 34989 2014-01-22 16:59:54Z hbfl $
#
# Copyright (c) 2006-2014 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-----------------------------------------------------------------------------

# set packages name
package_name=usb

# include configlib
. /var/install/include/configlib

#------------------------------------------------------------------------------
# set default values for configuration
#------------------------------------------------------------------------------
START_USB='no'

#USB_LOWLEVEL='uhci'

#USB_2='no'
USB_PRINTER='no'
USB_STORAGE='no'

USB_SERIAL='no'
USB_SERIAL_DRIVER=''
USB_SERIAL_OPTIONS=''

#USB_DEP_SERVICE_N='2'
#USB_DEP_SERVICE_1_NAME=''
#USB_DEP_SERVICE_1_ACTIVE='no'
#USB_DEP_SERVICE_1_DEVICE='usbcam'
#USB_DEP_SERVICE_2_NAME=''
#USB_DEP_SERVICE_2_ACTIVE='no'
#USB_DEP_SERVICE_2_DEVICE='lprng'

#------------------------------------------------------------------------------
# read old configuration and rename old variables
#-----------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2006-10-29" "tu"
    # -----------------------------------------------------------------------

    # -----------------------------------------------------------------------
    printgroup "Basic configuration"
    # -----------------------------------------------------------------------

    printvar "START_USB"            "USE yes or no"
#    echo
#    printvar "USB_LOWLEVEL"         "driver for USB-Chipset"
    echo
#    printvar "USB_2"                "start USB2 support"
    printvar "USB_PRINTER"          "driver for usb-printer"
    printvar "USB_STORAGE"          "driver for usb-storage"

    # -----------------------------------------------------------------------
    printgroup "USB serial options"
    # -----------------------------------------------------------------------

    printvar "USB_SERIAL"           "Use yes or no, for driver USB to RS232 adaptors"
    printvar "USB_SERIAL_DRIVER"    "low level driver for USB serial"
    printvar "USB_SERIAL_OPTIONS"   "options USB serial driver"

#    # -----------------------------------------------------------------------
#    printgroup "USB dependent services"
#    # -----------------------------------------------------------------------
#
#    printvar "USB_DEP_SERVICE_N"    "how many dependent services"
#
#    idx=1
#    while [ "${idx}" -le "${USB_DEP_SERVICE_N}" ]
#    do
#
#        eval active='${USB_DEP_SERVICE_'${idx}'_ACTIVE}'
#        eval device='${USB_DEP_SERVICE_'${idx}'}'
#
#        case x${active} in
#            x)
#                eval USB_DEP_SERVICE_${idx}_ACTIVE="no"
#            ;;
#
#            x*)
#                # nothing to do
#            ;;
#        esac
#
#        case x${device} in
#            x)
#                eval USB_DEP_SERVICE_${idx}_DEVICE='${USB_DEP_SERVICE_'${idx}'_DEVICE}'
#            ;;
#
#            x*)
#                eval USB_DEP_SERVICE_${idx}_DEVICE='${device}'
#            ;;
#        esac
#
#        printvar "USB_DEP_SERVICE_${idx}_NAME" "Use a name what ever you want, it's only for you"
#        printvar "USB_DEP_SERVICE_${idx}_ACTIVE" "Use yes or no"
#        printvar "USB_DEP_SERVICE_${idx}_DEVICE" "Use the device name, like lprng or usbcam"
#
#    idx=`/usr/bin/expr ${idx} + 1`
#    done
#
    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}
#----------------------------------------------------------------------------
# create check.d file
#----------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2004-12-20' 'tu' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                OPT_VARIABLE              VARIABLE_N         VALUE
START_USB                 -                         -                  YESNO

#USB_LOWLEVEL              START_USB                 -                  USB_LOWLEVEL_DEVICE
#USB_2                     START_USB                 -                  YESNO
USB_PRINTER               START_USB                 -                  YESNO
USB_STORAGE               START_USB                 -                  YESNO
USB_STORAGE               START_USB                 -                  YESNO

USB_SERIAL                START_USB                 -                  YESNO
USB_SERIAL_DRIVER         USB_SERIAL                -                  NOTEMPTY
USB_SERIAL_OPTIONS        USB_SERIAL                -                  NONE

#USB_DEP_SERVICE_N         START_USB                 -                  NUMERIC
#USB_DEP_SERVICE_%_NAME    START_USB                 USB_DEP_SERVICE_N  NONE
#USB_DEP_SERVICE_%_ACTIVE  START_USB                 USB_DEP_SERVICE_N  YESNO
#USB_DEP_SERVICE_%_DEVICE  USB_DEP_SERVICE_%_ACTIVE  USB_DEP_SERVICE_N  NOTEMPTY
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}


#printgpl --check_exp ${package_name} '2006-11-09' 'hbfl' >/etc/check.d/${package_name}.exp
#cat >>/etc/check.d/${package_name}.exp <<EOF
#USB_LOWLEVEL_DEVICE = 'uhci|usb-ohci|usb-uhci|uhci-hcd|ohci-hcd'
#                    : 'Use only  uhci, usb-ohci, usb-uhci, uhci-hcd or ohci-hcd'
#EOF
#
#    # Set rights for check.exp file
#    chmod 0600 /etc/check.d/${package_name}.exp
#    chown root /etc/check.d/${package_name}.exp
}
# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
# write default config file
make_config_file /etc/default.d/${package_name}

# update from old version
rename_old_variables

# write new config file
make_config_file /etc/config.d/${package_name}

# write check.d file
make_check_file

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
